@@ -218,9 +218,9 @@ def bazos_one_word(exp, blacklist, wordcore, word_decl, word_decl_re):
                     pass
                 else:
                     pricepool = anno.find('div', {'class', 'inzeratycena'}).text
-                    try:
+                    if re.search('(.+?) Kč', str(pricepool)):
                         price = int(re.search('(.+?) Kč', str(pricepool)).group(1).replace(" ", ""))
-                    except [TypeError, ValueError]:
+                    else:
                         price = 0
                     currency = "Kč"
                     if price == 0:
